@@ -4,6 +4,7 @@ This module provides an interface for invoking CMake executable.
 
 
 import argparse
+import configparser
 import contextlib
 import glob
 import itertools
@@ -303,7 +304,7 @@ class CMaker:
 
         if generator.toolset:
             cmd.extend(["-T", generator.toolset])
-        if generator.architecture:
+        if generator.architecture and "Visual Studio" in generator.name:
             cmd.extend(["-A", generator.architecture])
         if ninja_executable_path is not None:
             cmd.append(f"-DCMAKE_MAKE_PROGRAM:FILEPATH={ninja_executable_path}")
@@ -368,6 +369,8 @@ class CMaker:
         if not python_version:
             python_version = ".".join(map(str, sys.version_info[:2]))
 
+        assert isinstance(python_version, str)
+
         return python_version
 
     # NOTE(opadron): The try-excepts raise the cyclomatic complexity, but we
@@ -477,12 +480,23 @@ class CMaker:
             >>> print('python_library = {!r}'.format(python_library))
             python_library = '.../conda/envs/py37/include/python3.7m'
         """
+        # On Windows, support cross-compiling in the same way as setuptools
+        # When cross-compiling, check DIST_EXTRA_CONFIG first
+        config_file = os.environ.get("DIST_EXTRA_CONFIG", None)
+        if config_file and Path(config_file).is_file():
+            cp = configparser.ConfigParser()
+            cp.read(config_file)
+            result = cp.get("build_ext", "library_dirs", fallback="")
+            if result:
+                minor = sys.version_info[1]
+                return str(Path(result) / f"python3{minor}.lib")
+
         # This seems to be the simplest way to detect the library path with
         # modern python versions that avoids the complicated construct below.
         # It avoids guessing the library name. Tested with cpython 3.8 and
         # pypy 3.8 on Ubuntu.
-        libdir = sysconfig.get_config_var("LIBDIR")
-        ldlibrary = sysconfig.get_config_var("LDLIBRARY")
+        libdir: Optional[str] = sysconfig.get_config_var("LIBDIR")
+        ldlibrary: Optional[str] = sysconfig.get_config_var("LDLIBRARY")
         if libdir and ldlibrary and os.path.exists(libdir):
             if sysconfig.get_config_var("MULTIARCH"):
                 masd = sysconfig.get_config_var("multiarchsubdir")
@@ -493,7 +507,7 @@ class CMaker:
                     if os.path.exists(libdir_masd):
                         libdir = libdir_masd
             libpath = os.path.join(libdir, ldlibrary)
-            if os.path.exists(libpath):
+            if libpath and os.path.exists(libpath):
                 return libpath
 
         return CMaker._guess_python_library(python_version)
@@ -501,7 +515,7 @@ class CMaker:
     @staticmethod
     def _guess_python_library(python_version: str) -> Optional[str]:
         # determine direct path to libpython
-        python_library = sysconfig.get_config_var("LIBRARY")
+        python_library: Optional[str] = sysconfig.get_config_var("LIBRARY")
 
         # if static (or nonexistent), try to find a suitable dynamic libpython
         if not python_library or os.path.splitext(python_library)[1][-2:] == ".a":
