@@ -7,7 +7,7 @@ import setuptools  # noqa: F401
 from distutils.command.clean import clean as _clean
 
 from ..constants import CMAKE_BUILD_DIR, CMAKE_INSTALL_DIR, SKBUILD_DIR
-from ..utils import distutils_log
+from ..utils import logger
 from . import set_build_base_mixin
 
 
@@ -20,7 +20,7 @@ class clean(set_build_base_mixin, _clean):
         super().run()
         for dir_ in (CMAKE_INSTALL_DIR(), CMAKE_BUILD_DIR(), SKBUILD_DIR()):
             if os.path.exists(dir_):
-                distutils_log.info("removing '%s'", dir_)
+                logger.info("removing '%s'", dir_)
             # This seems to be there but isn't typed in the stubs TODO
             if not self.dry_run and os.path.exists(dir_):  # type: ignore[attr-defined]
                 rmtree(dir_)
