@@ -5,7 +5,7 @@ from typing import List
 
 from setuptools.command.install_lib import install_lib as _install_lib
 
-from ..utils import distribution_hide_listing, distutils_log
+from ..utils import distribution_hide_listing, logger
 from . import CommandMixinProtocol, set_build_base_mixin
 
 
@@ -17,5 +17,5 @@ class install_lib(set_build_base_mixin, _install_lib):
         with distribution_hide_listing(self.distribution):
             outfiles: List[str] = super().install()  # type: ignore[misc]
         if outfiles is not None:
-            distutils_log.info("copied %d files", len(outfiles))
+            logger.info("copied %d files", len(outfiles))
         return outfiles
