@@ -5,7 +5,7 @@ from typing import Any
 
 from setuptools.command.install_scripts import install_scripts as _install_scripts
 
-from ..utils import distribution_hide_listing, distutils_log
+from ..utils import distribution_hide_listing, logger
 from . import CommandMixinProtocol, set_build_base_mixin
 
 
@@ -16,4 +16,4 @@ class install_scripts(set_build_base_mixin, _install_scripts):
         """Handle --hide-listing option."""
         with distribution_hide_listing(self.distribution):
             super().run(*args, **kwargs)  # type: ignore[misc]
-        distutils_log.info("copied %d files", len(self.outfiles))
+        logger.info("copied %d files", len(self.outfiles))
