@@ -4,7 +4,7 @@ from typing import Optional, Sequence
 
 from setuptools.command.sdist import sdist as _sdist
 
-from ..utils import distribution_hide_listing, distutils_log
+from ..utils import distribution_hide_listing, logger
 from . import CommandMixinProtocol, set_build_base_mixin
 
 
@@ -15,7 +15,7 @@ class sdist(set_build_base_mixin, _sdist):
         """Handle --hide-listing option."""
         with distribution_hide_listing(self.distribution):
             super().make_release_tree(base_dir, files)  # type: ignore[misc]
-        distutils_log.info("copied %d files", len(files))
+        logger.info("copied %d files", len(files))
 
     def make_archive(
         self,
@@ -27,7 +27,7 @@ class sdist(set_build_base_mixin, _sdist):
         group: Optional[str] = None,
     ) -> str:
         """Handle --hide-listing option."""
-        distutils_log.info("creating '%s' %s archive and adding '%s' to it", base_name, _format, base_dir)
+        logger.info("creating '%s' %s archive and adding '%s' to it", base_name, _format, base_dir)
         with distribution_hide_listing(self.distribution):  # type: ignore[attr-defined]
             return super().make_archive(base_name, _format, root_dir, base_dir, owner, group)
 
