@@ -3,13 +3,12 @@
 from setuptools.command.test import test as _test
 
 from . import set_build_base_mixin
-from ..utils import new_style
 
 
-class test(set_build_base_mixin, new_style(_test)):
+class test(set_build_base_mixin, _test):
     """Custom implementation of ``test`` setuptools command."""
 
-    def run(self, *args, **kwargs):
+    def run(self, *args: object, **kwargs: object) -> None:
         """Force ``develop`` command to run."""
-        self.run_command('develop')
-        super(test, self).run(*args, **kwargs)
+        self.run_command("develop")
+        super().run(*args, **kwargs)
