@@ -10,7 +10,7 @@ class OSXPlatform(unix.UnixPlatform):
     """OSX implementation of :class:`.abstract.CMakePlatform`."""
 
     @property
-    def generator_installation_help(self):
+    def generator_installation_help(self) -> str:
         """Return message guiding the user for installing a valid toolchain."""
         return (
             textwrap.dedent(
@@ -21,6 +21,6 @@ class OSXPlatform(unix.UnixPlatform):
               https://developer.apple.com/xcode/
             """
             )
-            .format(pyver="%s.%s" % sys.version_info[:2])
+            .format(pyver=".".join(str(v) for v in sys.version_info[:2]))
             .strip()
         )
