@@ -5,8 +5,10 @@
 
 import platform
 
+from . import abstract
 
-def get_platform():
+
+def get_platform() -> "abstract.CMakePlatform":
     """Return an instance of :class:`.abstract.CMakePlatform` corresponding
     to the current platform."""
     this_platform = platform.system().lower()
@@ -21,6 +23,11 @@ def get_platform():
 
         return linux.LinuxPlatform()
 
+    if this_platform.startswith("cygwin"):
+        from . import cygwin
+
+        return cygwin.CygwinPlatform()
+
     if this_platform == "darwin":
         from . import osx
 
@@ -31,5 +38,5 @@ def get_platform():
 
         return bsd.BSDPlatform()
 
-    msg = "Unsupported platform: {:s}. Please contact the scikit-build team.".format(this_platform)
+    msg = f"Unsupported platform: {this_platform:s}. Please contact the scikit-build team."
     raise RuntimeError(msg)
