@@ -4,9 +4,9 @@ setup(
     name="hello",
     version="1.2.3",
     description="a minimal example package",
-    author='The scikit-build team',
+    author="The scikit-build team",
     license="MIT",
-    packages=['hello'],
-    package_dir={'': 'src'},
-    test_suite='hello_tests'
+    packages=["hello"],
+    package_dir={"": "src"},
+    test_suite="hello_tests",
 )
