@@ -4,7 +4,7 @@ setup(
     name="manifest-in",
     version="1.2.3",
     description="a minimal example package with a MANIFEST.in",
-    author='The scikit-build team',
+    author="The scikit-build team",
     license="MIT",
-    packages=['hello'],
+    packages=["hello"],
 )
