@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """test_hello_cython
 ----------------------------------
@@ -9,9 +8,15 @@ Tries to build and test the `hello-cython` sample project.
 
 import glob
 
+import pytest
+
 from . import get_ext_suffix, project_setup_py_test
 from .pytest_helpers import check_sdist_content, check_wheel_content
 
+pytestmark = pytest.mark.filterwarnings(
+    "ignore:.*ends with a trailing slash, which is not supported by setuptools:FutureWarning"
+)
+
 
 @project_setup_py_test("hello-cython", ["build"])
 def test_hello_cython_builds():
