@@ -1,4 +1,5 @@
 import os
+import platform
 import subprocess
 import sys
 
@@ -10,5 +11,9 @@ BASE = os.path.dirname(DIR)
 
 
 @pytest.mark.skipif(sys.platform.startswith("cygwin"), reason="Needs release of scikit-build to make cmake work")
+@pytest.mark.skipif(
+    platform.python_implementation() == "PyPy" and sys.version_info >= (3, 9),
+    reason="NumPy not released for PyPy 3.9 yet",
+)
 def test_pep518_findpython(pep518):
     subprocess.check_call([sys.executable, "-m", "build", "--wheel"], cwd=HELLO_NUMPY)
